@@ -1,3 +1,27 @@
+/*
+ * Dropbear - a SSH2 server
+ * 
+ * Copyright (c) 2002,2003 Matt Johnston
+ * All rights reserved.
+ * 
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following condition:
+ * 
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ * 
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ * SOFTWARE. */
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -5,8 +29,6 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
-
-
 #include "options.h"
 #include "util.h"
 #include "signkey.h"
@@ -15,7 +37,6 @@
 #include "buffer.h"
 #include "gendss.h"
 #include "dss.h"
-#include "libtomcrypt/mpi.h"
 #include "libtomcrypt/mycrypt.h"
 
 #define PSIZE 128 /* 1024 bit*/
@@ -46,7 +67,7 @@ dss_key * gen_dss_priv_key(unsigned int size) {
 	key->x = (mp_int*)m_malloc(sizeof(mp_int));
 	m_mp_init(key->x);
 	
-	initrandom();
+	seedrandom();
 	
 	getq(key);
 	getp(key, size);
@@ -207,7 +228,7 @@ static void getx(dss_key *key) {
 	m_mp_init(&val);
 	
 	do {
-		genhighrandom(buf, QSIZE);
+		genrandom(buf, QSIZE);
 
 		if (mp_read_unsigned_bin(&val, buf, QSIZE) != MP_OKAY) {
 			fprintf(stderr, "dss key generation failed\n");
